@@ -4,10 +4,13 @@ from typing import TextIO
 try:
     from markupsafe import escape
     from markupsafe import Markup
+    from markupsafe import soft_str
 except ImportError:
     from liquid.exceptions import escape  # type: ignore
     from liquid.exceptions import Markup  # type: ignore
 
+    soft_str = str  # pylint: disable=invalid-name
+
 from liquid.ast import Node
 from liquid.context import Context
 from liquid.expression import Expression
@@ -38,9 +41,7 @@ class StatementNode(Node):
     def __repr__(self):  # pragma: no cover
         return f"StatementNode(tok={self.tok}, expression={self.expression!r})"
 
-    def render_to_output(self, context: Context, buffer: TextIO):
-        val = self.expression.evaluate(context)
-
+    def _to_liquid_string(self, val: object, autoescape: bool) -> str:
         if isinstance(val, str):
             # shortcut for common case.
             pass
@@ -48,20 +49,28 @@ class StatementNode(Node):
             val = str(val).lower()
         elif val is None:
             val = ""
-        elif isinstance(val, (list, tuple)):
-            if context.autoescape:
-                val = Markup("").join(_str_if_not(itm) for itm in val)
+        elif isinstance(val, list):
+            if autoescape:
+                val = Markup("").join(soft_str(itm) for itm in val)
             else:
-                val = "".join(_str_if_not(itm) for itm in val)
+                val = "".join(soft_str(itm) for itm in val)
         else:
             val = str(val)
 
         assert isinstance(val, str)
 
-        if context.autoescape:
+        if autoescape:
             val = escape(val)
 
-        buffer.write(val)
+        return val
+
+    def render_to_output(self, context: Context, buffer: TextIO):
+        val = self.expression.evaluate(context)
+        buffer.write(self._to_liquid_string(val, context.autoescape))
+
+    async def render_to_output_async(self, context: Context, buffer: TextIO):
+        val = await self.expression.evaluate_async(context)
+        buffer.write(self._to_liquid_string(val, context.autoescape))
 
 
 class Statement(Tag):
@@ -76,9 +85,3 @@ class Statement(Tag):
         expr_iter = tokenize_filtered_expression(tok.value)
         node = StatementNode(tok, parse_filtered_expression(TokenStream(expr_iter)))
         return node
-
-
-def _str_if_not(val: object) -> str:
-    if not isinstance(val, str):
-        return str(val)
-    return val
