@@ -48,6 +48,7 @@ from liquid.token import TOKEN_RANGE
 from liquid.token import TOKEN_LIMIT
 from liquid.token import TOKEN_OFFSET
 from liquid.token import TOKEN_REVERSED
+from liquid.token import TOKEN_CONTINUE
 from liquid.token import TOKEN_COLS
 from liquid.token import TOKEN_PIPE
 from liquid.token import TOKEN_COLON
@@ -174,6 +175,7 @@ loop_expression_keywords = frozenset(
         TOKEN_LIMIT,
         TOKEN_REVERSED,
         TOKEN_COLS,
+        TOKEN_CONTINUE,
     ]
 )
 
@@ -213,7 +215,7 @@ def compile_liquid_rules(
     tag_end_string: str = r"%}",
     statement_start_string: str = r"{{",
     statement_end_string: str = r"}}",
-):
+) -> Pattern:
     """Compile rules for lexing liquid templates."""
     tag_s = re.escape(tag_start_string)
     tag_e = re.escape(tag_end_string)
@@ -232,7 +234,7 @@ def compile_liquid_rules(
     return _compile_rules(liquid_rules)
 
 
-def _compile_rules(rules: Iterable[Tuple[str, str]]):
+def _compile_rules(rules: Iterable[Tuple[str, str]]) -> Pattern:
     """Compile the given rules into a single regular expression."""
     pattern = "|".join(f"(?P<{name}>{pattern})" for name, pattern in rules)
     return re.compile(pattern, re.DOTALL)
